[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Xen-changelog] [xen-unstable] [HVM] qemu should wait 10ms, rather than 100ms, between running its timers.



# HG changeset patch
# User Steven Smith <ssmith@xxxxxxxxxxxxx>
# Node ID 5c522692edd188b636b1f239f071540e94daf29f
# Parent  000aa9510e5587f869a743121dd06ad2e0f21a99
[HVM] qemu should wait 10ms, rather than 100ms, between running its timers.

Signed-off-by: Steven Smith <sos22@xxxxxxxxx>
---
 tools/ioemu/target-i386-dm/helper2.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff -r 000aa9510e55 -r 5c522692edd1 tools/ioemu/target-i386-dm/helper2.c
--- a/tools/ioemu/target-i386-dm/helper2.c      Wed Sep 27 14:30:36 2006 +0100
+++ b/tools/ioemu/target-i386-dm/helper2.c      Wed Sep 27 16:22:17 2006 +0100
@@ -520,8 +520,8 @@ int main_loop(void)
             }
         }
 
-        /* Wait up to 100 msec. */
-        main_loop_wait(100);
+        /* Wait up to 10 msec. */
+        main_loop_wait(10);
 
         if (env->send_event) {
             env->send_event = 0;

_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog


 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.